@@ -1,8 +1,8 @@
 CLI_CONFIG = {
-    "serialize_plugin": {},
+    "serial_plugin": {},
 }
 CONFIG = {
-    "serialize_plugin": {
+    "serial_plugin": {
         "help": "The plugin used to serialize data. Defaults to json",
         "default": "json",
     },
@@ -11,6 +11,5 @@ DYNE = {
     "log": ["log"],
     "evbus": ["evbus"],
     "ingress": ["ingress"],
-    "serialize": ["serialize"],
     "match": ["match"],
 }
