@@ -27,12 +27,14 @@ async def profiles(
             profiles = [profiles]
         for profile in profiles:
             for name, info in profile.items():
-                ret_data[provider].append(data.NamespaceDict({name: info}))
+                new_ctx = data.NamespaceDict({name: info})
+                ret_data[provider].append(new_ctx)
                 if provider in hub.acct:
                     # This profile needs to run through an acct plugin for processing
                     new_info = await hub.acct.init.process(
-                        {provider}, {provider: {name: info}}
+                        {provider}, {provider: new_ctx}
                     )
-                    ret_data[provider].append(data.NamespaceDict({name: new_info}))
+                    if new_info[provider]:
+                        ret_data[provider].append(data.NamespaceDict({name: new_info}))
 
     return ret_data
