@@ -10,14 +10,14 @@ import dict_tools.data as data
 
 def __init__(hub):
     # Start off with a synchronous queue
+    hub.evbus.SERIAL_PLUGIN = "json"
     hub.evbus.BUS = queue.Queue()
 
 
 @dataclasses.dataclass
 class Event:
     profile: str
-    routing_key: str
-    body: str
+    body: bytes
 
 
 async def get(hub):
@@ -40,27 +40,25 @@ async def init(hub):
     return hub.evbus.BUS
 
 
-async def put(hub, routing_key: str, body: str, profile: str = "default"):
+async def put(hub, body: str, profile: str = "default"):
     """
     Put an event on the bus as a single data class
     :param hub:
-    :param routing_key: The channel to forward the message body to
     :param body: The message body that will be serialized and put on the bus
     :param profile: The ctx profile name that should be used for this message
+    :param serial_plugin: The pop-serial plugin used to serialize data
     """
+    serialized: bytes = hub.serial[hub.evbus.SERIAL_PLUGIN].dump(body)
     bus: asyncio.Queue = await hub.evbus.broker.init()
-    serialized = hub.serialize[hub.serialize.PLUGIN].apply(body)
-    await bus.put(Event(routing_key=routing_key, body=serialized, profile=profile))
+    await bus.put(Event(body=serialized, profile=profile))
 
 
-def put_nowait(hub, routing_key: str, body: str, profile: str = "default"):
+def put_nowait(hub, body: str, profile: str = "default"):
     """
     Put an event on the bus as a single data class
     """
-    serialized = hub.serialize[hub.serialize.PLUGIN].apply(body)
-    hub.evbus.BUS.put_nowait(
-        Event(routing_key=routing_key, body=serialized, profile=profile)
-    )
+    serialized: bytes = hub.serial[hub.evbus.SERIAL_PLUGIN].dump(body)
+    hub.evbus.BUS.put_nowait(Event(body=serialized, profile=profile))
 
 
 async def propagate(
@@ -90,11 +88,7 @@ async def propagate(
                     # Treat the profile name as a pattern, and see if the event profile name matches
                     if hub.match[match_plugin].find(name=event.profile, pattern=name):
                         ctx = data.NamespaceDict(acct=profile[name])
-                        coros.append(
-                            plugin.publish(
-                                ctx=ctx, routing_key=event.routing_key, body=event.body
-                            )
-                        )
+                        coros.append(plugin.publish(ctx=ctx, body=event.body))
 
     for task in asyncio.as_completed(coros):
         # Don't stop the listener for a failure
