@@ -8,7 +8,7 @@ STOP_ITERATION = object()
 
 def __init__(hub):
     hub.evbus.STARTED = False
-    for dyne in ("acct", "ingress", "output", "serialize", "match"):
+    for dyne in ("acct", "ingress", "output", "serial", "match"):
         hub.pop.sub.add(dyne_name=dyne)
 
 
